pub fn inspect_node_uri(
uri: String,
) -> Result<NodeUriPreviewRecord, MobileError>Expand description
Parse a node URI locally and return only validated public identity fields.
pub fn inspect_node_uri(
uri: String,
) -> Result<NodeUriPreviewRecord, MobileError>Parse a node URI locally and return only validated public identity fields.