pub struct MobileChatOriginalRef {
pub session_id: u64,
pub handle: u32,
pub wire_id: Option<u8>,
pub epoch: Option<u16>,
}Expand description
Platform-persisted identity of a previously composed outbound message,
used to target an edit or delete. session_id/handle identify it when
composed by the current facade session; wire_id/epoch are the durable
fallback for messages composed before a restart.
Fields
session_id: u64handle: u32wire_id: Option<u8>epoch: Option<u16>Trait Implementations
Sourceimpl Clone for MobileChatOriginalRef
impl Clone for MobileChatOriginalRef
Sourcefn clone(&self) -> MobileChatOriginalRef
fn clone(&self) -> MobileChatOriginalRef
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<UT> ConvertError<UT> for MobileChatOriginalRef
impl<UT> ConvertError<UT> for MobileChatOriginalRef
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl Debug for MobileChatOriginalRef
impl Debug for MobileChatOriginalRef
Sourceimpl<UT> FfiConverter<UT> for MobileChatOriginalRef
impl<UT> FfiConverter<UT> for MobileChatOriginalRef
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a MetadataBuffer.
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl<UT> Lift<UT> for MobileChatOriginalRef
impl<UT> Lift<UT> for MobileChatOriginalRef
Sourceimpl<UT> LiftRef<UT> for MobileChatOriginalRef
impl<UT> LiftRef<UT> for MobileChatOriginalRef
Sourceimpl<UT> LiftReturn<UT> for MobileChatOriginalRef
impl<UT> LiftReturn<UT> for MobileChatOriginalRef
Sourcetype ReturnType = <MobileChatOriginalRef as Lift<UT>>::FfiType
type ReturnType = <MobileChatOriginalRef as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
Sourcefn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
Sourcefn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
Sourcefn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for MobileChatOriginalRef
impl<UT> Lower<UT> for MobileChatOriginalRef
type FfiType = <MobileChatOriginalRef as FfiConverter<UT>>::FfiType
fn lower(obj: Self) -> Self::FfiType
fn write(obj: Self, buf: &mut Vec<u8>)
Sourcefn lower_into_rust_buffer(obj: Self) -> RustBuffer
fn lower_into_rust_buffer(obj: Self) -> RustBuffer
Convenience method
Sourceimpl<UT> LowerError<UT> for MobileChatOriginalRef
impl<UT> LowerError<UT> for MobileChatOriginalRef
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for MobileChatOriginalRef
impl<UT> LowerReturn<UT> for MobileChatOriginalRef
Sourcetype ReturnType = <MobileChatOriginalRef as Lower<UT>>::FfiType
type ReturnType = <MobileChatOriginalRef as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
Sourcefn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl PartialEq for MobileChatOriginalRef
impl PartialEq for MobileChatOriginalRef
Sourceimpl<UT> TypeId<UT> for MobileChatOriginalRef
impl<UT> TypeId<UT> for MobileChatOriginalRef
impl Eq for MobileChatOriginalRef
impl StructuralPartialEq for MobileChatOriginalRef