pub struct MobileIdentity { /* private fields */ }Expand description
Identity secret retained by the Rust engine after one controlled unlock transfer. Swift receives only public identity records from this object.
Implementations
Sourceimpl MobileIdentity
impl MobileIdentity
pub fn unlock(secret_key: Vec<u8>) -> Result<Arc<Self>, MobileError>
pub fn public_identity(&self) -> PublicIdentityRecord