pub struct MobileMeshPingEventRecord {
pub operation_id: u64,
pub outcome: MobileMeshPingOutcome,
pub round_trip_milliseconds: Option<u64>,
pub hop_count: Option<u8>,
pub route_hints: Vec<Vec<u8>>,
pub rssi_dbm: Option<i16>,
pub snr_centibels: Option<i16>,
pub lqi: Option<u8>,
}Fields
operation_id: u64outcome: MobileMeshPingOutcomeround_trip_milliseconds: Option<u64>hop_count: Option<u8>Total radio links traversed by the response, when the wire metadata can determine it. A direct response is one hop.
route_hints: Vec<Vec<u8>>Authenticated intermediate-router hints, in source-to-destination order. The two endpoints are not included.
rssi_dbm: Option<i16>Signal measurements for the final radio hop into this device.
snr_centibels: Option<i16>lqi: Option<u8>Trait Implementations
Sourceimpl Clone for MobileMeshPingEventRecord
impl Clone for MobileMeshPingEventRecord
Sourcefn clone(&self) -> MobileMeshPingEventRecord
fn clone(&self) -> MobileMeshPingEventRecord
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<UT> ConvertError<UT> for MobileMeshPingEventRecord
impl<UT> ConvertError<UT> for MobileMeshPingEventRecord
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl Debug for MobileMeshPingEventRecord
impl Debug for MobileMeshPingEventRecord
Sourceimpl<UT> FfiConverter<UT> for MobileMeshPingEventRecord
impl<UT> FfiConverter<UT> for MobileMeshPingEventRecord
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a MetadataBuffer.
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl<UT> Lift<UT> for MobileMeshPingEventRecord
impl<UT> Lift<UT> for MobileMeshPingEventRecord
Sourceimpl<UT> LiftRef<UT> for MobileMeshPingEventRecord
impl<UT> LiftRef<UT> for MobileMeshPingEventRecord
Sourceimpl<UT> LiftReturn<UT> for MobileMeshPingEventRecord
impl<UT> LiftReturn<UT> for MobileMeshPingEventRecord
Sourcetype ReturnType = <MobileMeshPingEventRecord as Lift<UT>>::FfiType
type ReturnType = <MobileMeshPingEventRecord as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
Sourcefn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
Sourcefn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
Sourcefn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for MobileMeshPingEventRecord
impl<UT> Lower<UT> for MobileMeshPingEventRecord
type FfiType = <MobileMeshPingEventRecord as FfiConverter<UT>>::FfiType
fn lower(obj: Self) -> Self::FfiType
fn write(obj: Self, buf: &mut Vec<u8>)
Sourcefn lower_into_rust_buffer(obj: Self) -> RustBuffer
fn lower_into_rust_buffer(obj: Self) -> RustBuffer
Convenience method
Sourceimpl<UT> LowerError<UT> for MobileMeshPingEventRecord
impl<UT> LowerError<UT> for MobileMeshPingEventRecord
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for MobileMeshPingEventRecord
impl<UT> LowerReturn<UT> for MobileMeshPingEventRecord
Sourcetype ReturnType = <MobileMeshPingEventRecord as Lower<UT>>::FfiType
type ReturnType = <MobileMeshPingEventRecord as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
Sourcefn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl<UT> TypeId<UT> for MobileMeshPingEventRecord
impl<UT> TypeId<UT> for MobileMeshPingEventRecord
impl Eq for MobileMeshPingEventRecord
impl StructuralPartialEq for MobileMeshPingEventRecord