pub struct MobileMeshSessionUpdateRecord {
pub outbound_frames: Vec<MobileMeshOutboundFrameRecord>,
pub ping_events: Vec<MobileMeshPingEventRecord>,
pub advertisement_events: Vec<MobileMeshAdvertisementRecord>,
pub peer_heard_events: Vec<MobileMeshPeerHeardRecord>,
pub chat_batch_id: Option<u64>,
pub chat_mutations: Vec<MobileChatMutationRecord>,
pub chat_deliveries: Vec<MobileChatDeliveryRecord>,
pub chat_archive_lookups: Vec<MobileChatArchiveLookupRecord>,
pub chat_sender_resolutions: Vec<MobileChatSenderResolutionRecord>,
pub chat_diagnostics: Vec<String>,
}Fields
outbound_frames: Vec<MobileMeshOutboundFrameRecord>Complete raw UMSH frames ready for the ULCP PHY transport. Each frame must be completed after the device reports the physical radio result; queue acceptance is not transmit completion.
ping_events: Vec<MobileMeshPingEventRecord>advertisement_events: Vec<MobileMeshAdvertisementRecord>peer_heard_events: Vec<MobileMeshPeerHeardRecord>chat_batch_id: Option<u64>Chat effects remain in the facade until Swift durably applies them and acknowledges this batch. Repeated polls may return the same batch.
chat_mutations: Vec<MobileChatMutationRecord>chat_deliveries: Vec<MobileChatDeliveryRecord>chat_archive_lookups: Vec<MobileChatArchiveLookupRecord>chat_sender_resolutions: Vec<MobileChatSenderResolutionRecord>Channel members whose claimed hint has resolved to a full address. The platform should upgrade rows it stored anonymously under that hint.
chat_diagnostics: Vec<String>Trait Implementations
Sourceimpl Clone for MobileMeshSessionUpdateRecord
impl Clone for MobileMeshSessionUpdateRecord
Sourcefn clone(&self) -> MobileMeshSessionUpdateRecord
fn clone(&self) -> MobileMeshSessionUpdateRecord
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<UT> ConvertError<UT> for MobileMeshSessionUpdateRecord
impl<UT> ConvertError<UT> for MobileMeshSessionUpdateRecord
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl<UT> FfiConverter<UT> for MobileMeshSessionUpdateRecord
impl<UT> FfiConverter<UT> for MobileMeshSessionUpdateRecord
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a MetadataBuffer.
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl<UT> Lift<UT> for MobileMeshSessionUpdateRecord
impl<UT> Lift<UT> for MobileMeshSessionUpdateRecord
Sourceimpl<UT> LiftRef<UT> for MobileMeshSessionUpdateRecord
impl<UT> LiftRef<UT> for MobileMeshSessionUpdateRecord
Sourceimpl<UT> LiftReturn<UT> for MobileMeshSessionUpdateRecord
impl<UT> LiftReturn<UT> for MobileMeshSessionUpdateRecord
Sourcetype ReturnType = <MobileMeshSessionUpdateRecord as Lift<UT>>::FfiType
type ReturnType = <MobileMeshSessionUpdateRecord as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
Sourcefn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
Sourcefn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
Sourcefn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for MobileMeshSessionUpdateRecord
impl<UT> Lower<UT> for MobileMeshSessionUpdateRecord
type FfiType = <MobileMeshSessionUpdateRecord as FfiConverter<UT>>::FfiType
fn lower(obj: Self) -> Self::FfiType
fn write(obj: Self, buf: &mut Vec<u8>)
Sourcefn lower_into_rust_buffer(obj: Self) -> RustBuffer
fn lower_into_rust_buffer(obj: Self) -> RustBuffer
Convenience method
Sourceimpl<UT> LowerError<UT> for MobileMeshSessionUpdateRecord
impl<UT> LowerError<UT> for MobileMeshSessionUpdateRecord
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for MobileMeshSessionUpdateRecord
impl<UT> LowerReturn<UT> for MobileMeshSessionUpdateRecord
Sourcetype ReturnType = <MobileMeshSessionUpdateRecord as Lower<UT>>::FfiType
type ReturnType = <MobileMeshSessionUpdateRecord as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
Sourcefn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl<UT> TypeId<UT> for MobileMeshSessionUpdateRecord
impl<UT> TypeId<UT> for MobileMeshSessionUpdateRecord
impl Eq for MobileMeshSessionUpdateRecord
impl StructuralPartialEq for MobileMeshSessionUpdateRecord