pub struct NodeIdentityRecord {
pub role_code: u8,
pub role_label: String,
pub capabilities: Vec<String>,
pub capability_bits: u8,
pub name: Option<String>,
pub latitude: Option<f64>,
pub longitude: Option<f64>,
pub location_precision: Option<u8>,
pub altitude_m: Option<i32>,
pub timestamp: Option<u32>,
pub signature: IdentitySignatureState,
}Expand description
Decoded advertised node identity (node-identity.md), UI-safe fields only.
Fields
role_code: u8role_label: StringCanonical English role label; UI may localize by role_code.
capabilities: Vec<String>Canonical capability labels in wire bit order.
capability_bits: u8The same capabilities as the advertised bitfield, for filtering. Bits this build has no label for are still set here.
name: Option<String>latitude: Option<f64>Center of the advertised location grid cell, in degrees.
longitude: Option<f64>location_precision: Option<u8>Grid-code precision in bytes (1-7); larger is finer.
altitude_m: Option<i32>timestamp: Option<u32>Seconds since the Unix epoch (freshness marker).
signature: IdentitySignatureStateTrait Implementations
Sourceimpl Clone for NodeIdentityRecord
impl Clone for NodeIdentityRecord
Sourcefn clone(&self) -> NodeIdentityRecord
fn clone(&self) -> NodeIdentityRecord
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<UT> ConvertError<UT> for NodeIdentityRecord
impl<UT> ConvertError<UT> for NodeIdentityRecord
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl Debug for NodeIdentityRecord
impl Debug for NodeIdentityRecord
Sourceimpl<UT> FfiConverter<UT> for NodeIdentityRecord
impl<UT> FfiConverter<UT> for NodeIdentityRecord
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a MetadataBuffer.
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl<UT> Lift<UT> for NodeIdentityRecord
impl<UT> Lift<UT> for NodeIdentityRecord
Sourceimpl<UT> LiftRef<UT> for NodeIdentityRecord
impl<UT> LiftRef<UT> for NodeIdentityRecord
Sourceimpl<UT> LiftReturn<UT> for NodeIdentityRecord
impl<UT> LiftReturn<UT> for NodeIdentityRecord
Sourcetype ReturnType = <NodeIdentityRecord as Lift<UT>>::FfiType
type ReturnType = <NodeIdentityRecord as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
Sourcefn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
Sourcefn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
Sourcefn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for NodeIdentityRecord
impl<UT> Lower<UT> for NodeIdentityRecord
type FfiType = <NodeIdentityRecord as FfiConverter<UT>>::FfiType
fn lower(obj: Self) -> Self::FfiType
fn write(obj: Self, buf: &mut Vec<u8>)
Sourcefn lower_into_rust_buffer(obj: Self) -> RustBuffer
fn lower_into_rust_buffer(obj: Self) -> RustBuffer
Convenience method
Sourceimpl<UT> LowerError<UT> for NodeIdentityRecord
impl<UT> LowerError<UT> for NodeIdentityRecord
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for NodeIdentityRecord
impl<UT> LowerReturn<UT> for NodeIdentityRecord
Sourcetype ReturnType = <NodeIdentityRecord as Lower<UT>>::FfiType
type ReturnType = <NodeIdentityRecord as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
Sourcefn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl PartialEq for NodeIdentityRecord
impl PartialEq for NodeIdentityRecord
Sourceimpl<UT> TypeId<UT> for NodeIdentityRecord
impl<UT> TypeId<UT> for NodeIdentityRecord
impl StructuralPartialEq for NodeIdentityRecord