pub struct UlcpRadioSettingsRecord {
pub device_name: Option<String>,
pub phy_enabled: bool,
pub frequency_khz: u32,
pub transmit_power_dbm: i8,
pub bandwidth_hz: Option<u32>,
pub spreading_factor: Option<u8>,
pub coding_rate_denom: Option<u8>,
pub duty_cycle_limit: Option<u16>,
}Expand description
Complete desired live radio configuration. Capability-gated fields must be omitted when the device does not advertise their associated capability.
Fields
device_name: Option<String>phy_enabled: boolfrequency_khz: u32transmit_power_dbm: i8bandwidth_hz: Option<u32>spreading_factor: Option<u8>coding_rate_denom: Option<u8>duty_cycle_limit: Option<u16>Trait Implementations
Sourceimpl Clone for UlcpRadioSettingsRecord
impl Clone for UlcpRadioSettingsRecord
Sourcefn clone(&self) -> UlcpRadioSettingsRecord
fn clone(&self) -> UlcpRadioSettingsRecord
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<UT> ConvertError<UT> for UlcpRadioSettingsRecord
impl<UT> ConvertError<UT> for UlcpRadioSettingsRecord
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl Debug for UlcpRadioSettingsRecord
impl Debug for UlcpRadioSettingsRecord
Sourceimpl<UT> FfiConverter<UT> for UlcpRadioSettingsRecord
impl<UT> FfiConverter<UT> for UlcpRadioSettingsRecord
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a MetadataBuffer.
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl<UT> Lift<UT> for UlcpRadioSettingsRecord
impl<UT> Lift<UT> for UlcpRadioSettingsRecord
Sourceimpl<UT> LiftRef<UT> for UlcpRadioSettingsRecord
impl<UT> LiftRef<UT> for UlcpRadioSettingsRecord
Sourceimpl<UT> LiftReturn<UT> for UlcpRadioSettingsRecord
impl<UT> LiftReturn<UT> for UlcpRadioSettingsRecord
Sourcetype ReturnType = <UlcpRadioSettingsRecord as Lift<UT>>::FfiType
type ReturnType = <UlcpRadioSettingsRecord as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
Sourcefn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
Sourcefn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
Sourcefn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for UlcpRadioSettingsRecord
impl<UT> Lower<UT> for UlcpRadioSettingsRecord
type FfiType = <UlcpRadioSettingsRecord as FfiConverter<UT>>::FfiType
fn lower(obj: Self) -> Self::FfiType
fn write(obj: Self, buf: &mut Vec<u8>)
Sourcefn lower_into_rust_buffer(obj: Self) -> RustBuffer
fn lower_into_rust_buffer(obj: Self) -> RustBuffer
Convenience method
Sourceimpl<UT> LowerError<UT> for UlcpRadioSettingsRecord
impl<UT> LowerError<UT> for UlcpRadioSettingsRecord
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for UlcpRadioSettingsRecord
impl<UT> LowerReturn<UT> for UlcpRadioSettingsRecord
Sourcetype ReturnType = <UlcpRadioSettingsRecord as Lower<UT>>::FfiType
type ReturnType = <UlcpRadioSettingsRecord as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
Sourcefn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl PartialEq for UlcpRadioSettingsRecord
impl PartialEq for UlcpRadioSettingsRecord
Sourceimpl<UT> TypeId<UT> for UlcpRadioSettingsRecord
impl<UT> TypeId<UT> for UlcpRadioSettingsRecord
impl Eq for UlcpRadioSettingsRecord
impl StructuralPartialEq for UlcpRadioSettingsRecord